@@ -13,9 +13,11 @@
         sol$CCA$centroids <- unique(sol$CCA$centroids)
     if (!is.null(sol$CCA$centroids)) {
         rs <- rowSums(sol$CCA$centroids^2)
-        sol$CCA$centroids <- sol$CCA$centroids[rs > 1e-4, , drop=FALSE]
+        sol$CCA$centroids <- sol$CCA$centroids[rs > 1e-04, , 
+                                               drop = FALSE]
     }
     sol$terms <- d$terms
+    sol$terminfo <- ordiTerminfo(d, data)
     sol$call <- match.call()
     sol$call[[1]] <- as.name("cca")
     sol$call$formula <- formula(d$terms, width.cutoff = 500)
